Package 'ggsegPower'

Title: Power Atlas for the 'ggseg' Ecosystem
Description: Power functional network cortical parcellation atlas for the 'ggseg' ecosystem. Provides a unified 'ggseg_atlas' object with 2D polygon geometry for use with 'ggseg'.
Authors: Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>)
Maintainer: Athanasia Mo Mowinckel <[email protected]>
License: MIT + file LICENSE
Version: 2.0.1
Built: 2026-05-23 09:18:02 UTC
Source: https://github.com/ggsegverse/ggsegPower

Help Index


Power Functional Network Cortical Parcellation

Description

Brain atlas for the Power cortical parcellation with 129 regions based on functional network organization of the human brain. Contains 2D polygon geometry for ggseg::geom_brain().

Usage

power()

Value

A ggseg.formats::ggseg_atlas object (cortical).

References

Power JD, Cohen AL, Nelson SM, Wig GS, Barnes KA, Church JA, Vogel AC, Laumann TO, Miezin FM, Schlaggar BL, Petersen SE (2011). Functional Network Organization of the Human Brain. Neuron, 72(4):665-678. doi:10.1016/j.neuron.2011.09.006

Examples

power()
plot(power())